quantizationtools.DistanceHeuristic
===================================

.. abjad-lineage:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.DistanceHeuristic

.. autoclass:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.DistanceHeuristic
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.DistanceHeuristic.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.DistanceHeuristic.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.DistanceHeuristic.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.DistanceHeuristic.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.DistanceHeuristic.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.DistanceHeuristic.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.DistanceHeuristic.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.DistanceHeuristic.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.DistanceHeuristic.__repr__
   :noindex:
